Documentation
¶
Overview ¶
Package protocol contains types for Camlistore protocol types.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type StatResponse ¶
type StatResponse struct {
Stat []blob.SizedRef `json:"stat"`
CanLongPoll bool `json:"canLongPoll"` // TODO: move this to discovery?
}
StatResponse is the JSON document returned from the blob batch stat handler.
See doc/protocol/blob-stat-protocol.txt.
func (*StatResponse) MarshalJSON ¶
func (p *StatResponse) MarshalJSON() ([]byte, error)
type UploadResponse ¶
type UploadResponse struct {
Received []blob.SizedRef `json:"received"`
ErrorText string `json:"errorText,omitempty"`
}
UploadResponse is the JSON document returned from the blob batch upload handler.
See doc/protocol/blob-upload-protocol.txt.
func (*UploadResponse) MarshalJSON ¶
func (p *UploadResponse) MarshalJSON() ([]byte, error)
Source Files
¶
- protocol.go
Click to show internal directories.
Click to hide internal directories.